changeset 67571:d263a07df092

(font-lock-keywords-alist): Rename `append' to `how'. (font-lock-add-keywords, font-lock-update-removed-keyword-alist): (font-lock-remove-keywords): Likewise.
author Romain Francoise <romain@orebokech.com>
date Wed, 14 Dec 2005 11:21:24 +0000
parents 96258e76ae94
children 3ee5685f7930
files lisp/ChangeLog lisp/font-lock.el
diffstat 2 files changed, 27 insertions(+), 21 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Wed Dec 14 10:20:03 2005 +0000
+++ b/lisp/ChangeLog	Wed Dec 14 11:21:24 2005 +0000
@@ -1,3 +1,9 @@
+2005-12-14  Romain Francoise  <romain@orebokech.com>
+
+	* font-lock.el (font-lock-keywords-alist): Rename `append' to `how'.
+	(font-lock-add-keywords, font-lock-update-removed-keyword-alist):
+	(font-lock-remove-keywords): Likewise.
+
 2005-12-14  Juri Linkov  <juri@jurta.org>
 
 	* log-view.el (log-view-diff): Doc fix.
--- a/lisp/font-lock.el	Wed Dec 14 10:20:03 2005 +0000
+++ b/lisp/font-lock.el	Wed Dec 14 11:21:24 2005 +0000
@@ -463,13 +463,13 @@
 (defvar font-lock-keywords-alist nil
   "Alist of additional `font-lock-keywords' elements for major modes.
 
-Each element has the form (MODE KEYWORDS . APPEND).
+Each element has the form (MODE KEYWORDS . HOW).
 `font-lock-set-defaults' adds the elements in the list KEYWORDS to
 `font-lock-keywords' when Font Lock is turned on in major mode MODE.
 
-If APPEND is nil, KEYWORDS are added at the beginning of
+If HOW is nil, KEYWORDS are added at the beginning of
 `font-lock-keywords'.  If it is `set', they are used to replace the
-value of `font-lock-keywords'.  If APPEND is any other non-nil value,
+value of `font-lock-keywords'.  If HOW is any other non-nil value,
 they are added at the end.
 
 This is normally set via `font-lock-add-keywords' and
@@ -650,15 +650,15 @@
     (font-lock-unfontify-buffer)
     (font-lock-turn-off-thing-lock)))
 
-(defun font-lock-add-keywords (mode keywords &optional append)
+(defun font-lock-add-keywords (mode keywords &optional how)
   "Add highlighting KEYWORDS for MODE.
 
 MODE should be a symbol, the major mode command name, such as `c-mode'
 or nil.  If nil, highlighting keywords are added for the current buffer.
 KEYWORDS should be a list; see the variable `font-lock-keywords'.
 By default they are added at the beginning of the current highlighting list.
-If optional argument APPEND is `set', they are used to replace the current
-highlighting list.  If APPEND is any other non-nil value, they are added at the
+If optional argument HOW is `set', they are used to replace the current
+highlighting list.  If HOW is any other non-nil value, they are added at the
 end of the current highlighting list.
 
 For example:
@@ -691,17 +691,17 @@
 see the variables `c-font-lock-extra-types', `c++-font-lock-extra-types',
 `objc-font-lock-extra-types' and `java-font-lock-extra-types'."
   (cond (mode
 	 ;; If MODE is non-nil, add the KEYWORDS and APPEND spec to
 	 ;; `font-lock-keywords-alist' so `font-lock-set-defaults' uses them.
-	 (let ((spec (cons keywords append)) cell)
+	 (let ((spec (cons keywords how)) cell)
 	   (if (setq cell (assq mode font-lock-keywords-alist))
-	       (if (eq append 'set)
+	       (if (eq how 'set)
 		   (setcdr cell (list spec))
 		 (setcdr cell (append (cdr cell) (list spec))))
 	     (push (list mode spec) font-lock-keywords-alist)))
 	 ;; Make sure that `font-lock-removed-keywords-alist' does not
 	 ;; contain the new keywords.
-	 (font-lock-update-removed-keyword-alist mode keywords append))
+	 (font-lock-update-removed-keyword-alist mode keywords how))
 	(t
 	 ;; Otherwise set or add the keywords now.
 	 ;; This is a no-op if it has been done already in this buffer
@@ -712,13 +712,13 @@
 	   (if was-compiled
 	       (setq font-lock-keywords (cadr font-lock-keywords)))
 	   ;; Now modify or replace them.
-	   (if (eq append 'set)
+	   (if (eq how 'set)
 	       (setq font-lock-keywords keywords)
 	     (font-lock-remove-keywords nil keywords) ;to avoid duplicates
 	     (let ((old (if (eq (car-safe font-lock-keywords) t)
 			    (cdr font-lock-keywords)
 			  font-lock-keywords)))
-	       (setq font-lock-keywords (if append
+	       (setq font-lock-keywords (if how
 					    (append old keywords)
 					  (append keywords old)))))
 	   ;; If the keywords were compiled before, compile them again.
@@ -726,7 +726,7 @@
 	       (set (make-local-variable 'font-lock-keywords)
 		    (font-lock-compile-keywords font-lock-keywords t)))))))
 
-(defun font-lock-update-removed-keyword-alist (mode keywords append)
+(defun font-lock-update-removed-keyword-alist (mode keywords how)
   "Update `font-lock-removed-keywords-alist' when adding new KEYWORDS to MODE."
   ;; When font-lock is enabled first all keywords in the list
   ;; `font-lock-keywords-alist' are added, then all keywords in the
@@ -736,7 +736,7 @@
   ;; will not take effect.
   (let ((cell (assq mode font-lock-removed-keywords-alist)))
     (if cell
-	(if (eq append 'set)
+	(if (eq how 'set)
 	    ;; A new set of keywords is defined.  Forget all about
 	    ;; our old keywords that should be removed.
 	    (setq font-lock-removed-keywords-alist
@@ -786,14 +786,14 @@
 	     ;; If MODE is non-nil, remove the KEYWORD from
 	     ;; `font-lock-keywords-alist'.
 	     (when top-cell
-	       (dolist (keyword-list-append-pair (cdr top-cell))
-		 ;; `keywords-list-append-pair' is a cons with a list of
-		 ;; keywords in the car top-cell and the original append
+	       (dolist (keyword-list-how-pair (cdr top-cell))
+		 ;; `keywords-list-how-pair' is a cons with a list of
+		 ;; keywords in the car top-cell and the original how
 		 ;; argument in the cdr top-cell.
-		 (setcar keyword-list-append-pair
-			 (delete keyword (car keyword-list-append-pair))))
-	       ;; Remove keyword list/append pair when the keyword list
-	       ;; is empty and append doesn't specify `set'.  (If it
+		 (setcar keyword-list-how-pair
+			 (delete keyword (car keyword-list-how-pair))))
+	       ;; Remove keyword list/how pair when the keyword list
+	       ;; is empty and how doesn't specify `set'.  (If it
 	       ;; should be deleted then previously deleted keywords
 	       ;; would appear again.)
 	       (let ((cell top-cell))
@@ -691,17 +691,17 @@
 `objc-font-lock-extra-types' and `java-font-lock-extra-types'."
   (cond (mode
-	 ;; If MODE is non-nil, add the KEYWORDS and APPEND spec to
+	 ;; If MODE is non-nil, add the KEYWORDS and HOW spec to
 	 ;; `font-lock-keywords-alist' so `font-lock-set-defaults' uses them.